import 'package:gui_app/const/colors.dart';
import 'package:gui_app/const/dimens.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:syncfusion_flutter_gauges/gauges.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:flutter_gen/gen_l10n/app_localizations.dart';
import 'package:gui_app/provider.dart';

class GaugeTarget extends ConsumerStatefulWidget {
  final double width;
  final double height;
  const GaugeTarget(
      {Key? key, this.width = double.infinity, this.height = double.infinity})
      : super(key: key);

  @override
  ConsumerState<GaugeTarget> createState() => _GaugeState();
}

class _GaugeState extends ConsumerState<GaugeTarget> {
  final TextEditingController _targetController =
      new TextEditingController(text: '');
  @override
  Widget build(BuildContext context) {
    final Size containerSize = MediaQuery.of(context).size;
    return SizedBox(
      width: widget.width,
      height: widget.height,
      child: Stack(
        alignment: AlignmentDirectional.bottomCenter,
        children: [
          SfRadialGauge(
            title: GaugeTitle(
              text: L10n.of(context)!.target + '[%]',
              textStyle: TextStyle(
                  fontSize: containerSize.width * gaugeTitleFontSizeRatio,
                  fontWeight: FontWeight.bold,
                  color: textColor),
            ),
            axes: <RadialAxis>[
              RadialAxis(
                canScaleToFit: true,
                minimum: 0,
                // Maximum value of 100 does not show 100 labels.
                maximum: 101,
                axisLabelStyle: GaugeTextStyle(color: textColor),
                ranges: <GaugeRange>[
                  GaugeRange(
                    startValue: 0,
                    endValue: 30,
                    color: lowGaugeColor,
                  ),
                  GaugeRange(
                      startValue: 30, endValue: 60, color: middleGaugeColor),
                  GaugeRange(
                      startValue: 60, endValue: 100, color: highGaugeColor),
                ],
                pointers: <GaugePointer>[
                  NeedlePointer(
                    value: ref.watch(sliderProvider.state).state.toDouble(),
                    needleEndWidth: containerSize.width * gaugeNeedleSizeRatio,
                    enableAnimation: true,
                    needleColor: textColor,
                    knobStyle: KnobStyle(color: knobColor),
                  )
                ],
                annotations: <GaugeAnnotation>[],
              ),
            ],
          ),
          // When using GaugeAnnotation to place TextFormField,
          // the place to touch and the place to type are misaligned.
          Container(
            // Use padding because the text will not appear
            // under the needle if align is used.
            width: 30,
            child: TextFormField(
              textAlign: TextAlign.center,
              textAlignVertical: TextAlignVertical(y: -1),
              controller: _targetController,
              keyboardType: TextInputType.number,
              inputFormatters: [
                FilteringTextInputFormatter.digitsOnly,
                LengthLimitingTextInputFormatter(3)
              ],
              style: TextStyle(
                  fontSize: containerSize.width * gaugeValueFontSizeRatio,
                  color: textColor),
              decoration: InputDecoration(
                  enabledBorder: InputBorder.none,
                  focusedBorder: InputBorder.none,
                  labelText:
                      ref.watch(sliderProvider.state).state.toStringAsFixed(0),
                  labelStyle: TextStyle(
                      fontSize: containerSize.width * gaugeValueFontSizeRatio,
                      color: textColor)),
              onFieldSubmitted: (newValue) {
                if (newValue.length == 0) {
                  return;
                }
                var inputValue = int.parse(newValue);
                if (inputValue > 100) {
                  inputValue = 100;
                }
                ref.watch(sliderProvider.state).state = inputValue;
                // Pressing Enter will clear the entered value.
                _targetController.clear();
              },
            ),
          ),
        ],
      ),
    );
  }
}
