#!/bin/bash -e

FLUTTER_CUSTOM_DEVICES="flutter_custom_devices.json"

if command -v gettext > /dev/null; then
    _gettext() { gettext -- "$@"; }
else
    _gettext() { printf -- "%s" "$@"; }
fi

prompt() {
    local var="$1"
    local prompt_fmt="$2"
    shift 2
    # shellcheck disable=SC2059 # fmt is a build time constant
    printf -- "$(_gettext "$prompt_fmt") " "$@"
    read -r "${var?}"
}

prompt_yesno() {
    local default="$1"
    shift 1
    local yesno

    while true; do
        prompt yesno "$@"
        [ -n "$yesno" ] || yesno="$default"
        case "$yesno" in
        [Yy]|[Yy][Ee][Ss]|[Tt][Rr][Uu][Ee]|1)
            return 0;;
        [Nn]|[Nn][Oo]|[Ff][Aa][Ll][Ss][Ee]|0)
            return 1;;
        esac
    done
}

if [[ ! -e "$HOME/.$FLUTTER_CUSTOM_DEVICES" ]]; then
    cp "config/$FLUTTER_CUSTOM_DEVICES" "$HOME/.$FLUTTER_CUSTOM_DEVICES"
else
    if ! cmp "$HOME/.$FLUTTER_CUSTOM_DEVICES" "config/$FLUTTER_CUSTOM_DEVICES" > /dev/null; then
        if prompt_yesno y "%s already exists, overwrite? [Y/n]" ".$FLUTTER_CUSTOM_DEVICES"; then
            cp "config/$FLUTTER_CUSTOM_DEVICES" "$HOME/.$FLUTTER_CUSTOM_DEVICES"
        fi
    fi
fi

if [[ ! -e "config/ssh/id_rsa" ]]; then
    ssh-keygen -f config/ssh/id_rsa
fi
